==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/ms/v20180408/models/ScanPermissionInfo.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ms.v20180408.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ScanPermissionInfo  extends AbstractModel{

    /**
    * 系统权限
    */
    @SerializedName("Permission")
    @Expose
    private String Permission;

    /**
     * 获取系统权限
     * @return Permission 系统权限
     */
    public String getPermission() {
        return this.Permission;
    }

    /**
     * 设置系统权限
     * @param Permission 系统权限
     */
    public void setPermission(String Permission) {
        this.Permission = Permission;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Permission", this.Permission);

    }
}

==> tencentcloud-sdk-java-3.1.72-sources.jar: com/tencentcloudapi/ms/v20180408/models/ScanPermissionInfo.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ms.v20180408.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class ScanPermissionInfo extends AbstractModel{

    /**
    * 系统权限
    */
    @SerializedName("Permission")
    @Expose
    private String Permission;

    /**
     * Get 系统权限 
     * @return Permission 系统权限
     */
    public String getPermission() {
        return this.Permission;
    }

    /**
     * Set 系统权限
     * @param Permission 系统权限
     */
    public void setPermission(String Permission) {
        this.Permission = Permission;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Permission", this.Permission);

    }
}
